%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% matlab (master) file to calibrate and analyse output and welfare gains
% due to global trade unions
%
% Alejandro Donado and Klaus Waelde 2012 Trade Unions Go Global!
%
% see www.waelde.com/pub
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% close all graphics windows and clear memory
    close; clear;

% display date
%    disp(date);
    
% general paras
    iniEndoParas = [15 2 .5 80];
    

%% estimate parameters by "exact MM" or load estimates
CalibrateAgain = 1; % 1: load paras and calibrate 0: load estimates and paras
if CalibrateAgain

    % load all parameters
    
        % parameters truely exogenous
            alpha = 1/3; phi = 1;
            q = .1; n = 1; N = 1;

        % paras from data
            zNorthData = .98; zSouthData = .9; YNorth = 38; YSouth = 5.8;
            NSouth = 2422/722; % inhabitants China + India divided by inhabitants G7
            zC = .99; % we want consumption and output maximizing level to be at .99

        % adjusted by hand to fix reasonable equilibrium interest rate
            KWorld = 300;   

        % preference parameter of planner
            mue = .96;
            
        % compute auxiliary Phi such that output maximizing level holds
            PHI = (1/zC - 1)*(1-alpha);
            
        % phi and PHI imply chi
            chi = phi/PHI;

        % all this gives set of exogenous parameters
            ExoParas = [alpha chi zNorthData zSouthData phi q n N NaN KWorld NSouth YNorth YSouth]; %NaN @ ExoParas(9) will be used for lambda

        % technical paras
            PreciFun = 1e-8; PreciTol = 1e-8; %1e-3;
            opt = optimset('Display', 'off', 'TolFun', PreciFun , 'TolX', PreciTol);

    % now start true calibration    
            fprintf('\n==== calibrating parameters by exact MM for two-country world ...\n\n')
                
            % find lambda
                CalibrateLambda = 0;
                if CalibrateLambda
                    %opt = []; %[-10 -.001]
                    %lambda0 = -1;
                    lambdaRange = [-1.5 -.09];
                    [lambda residua ExitFlag] = fzero('CapitalFlowTarget',lambdaRange,opt,ExoParas,PHI,opt,iniEndoParas); %find lambda such that res is zero
                    ExoParas(9) = lambda; % now save lambda at ExoParas(9) which was NaN above
                    fprintf('o\n');
                    fprintf('lambda right after estimation in Calib_.m is %g\n',lambda')
                    if ExitFlag < 0, ExitFlag, error('problem with ExitFlag'), end
                    disp('how exact are roots? Look at residua');
                    disp(residua);
                else
                    lambda = -1;
                    ExoParas(9) = lambda; % now save lambda at ExoParas(9) which was NaN above
                end

            % find b bSouth gamma KNorth again (already computed in CapitalFlowTarget)    
                [EndoValues res_fsolve exitflag] = fsolve('ExactMM',iniEndoParas,opt,ExoParas,PHI);
                %disp('how exact are roots? Look at residua');
                %disp(res_fsolve);

            % make them public
                b = EndoValues(1); bSouth = EndoValues(2); gamma = EndoValues(3); KNorth = EndoValues(4);
                
            % this fixes paras for rest of analyses
                parasNeu = [b bSouth gamma NaN NaN NaN mue]; % mue is here for historical reasons - should be in exoParas ...
                paras = [ExoParas parasNeu];

    % save estimates
        save estimates2countryWorld.mat
else
    load estimates2countryWorld.mat
end

% show calibrated and equilibrium values
    IntRateDisplay = IntRate(KNorth,paras,PHI,'North');
    fprintf('lambda: %g, b: %g, bSouth: %g, gamma: %g, KNorth: %g, rWorld: %g\n', lambda, b, bSouth, gamma, KNorth, IntRateDisplay);
    if gamma > 1 || gamma < 0
        error('gamma too large (or negative)')
    end
                

%% ranking of safety levels
   fprintf('\n==== ranking of safety levels\n\n')
 
    % for comparison purposes: autarky output maximizing safety level
        zY_aut = 1/(PHI/(1-alpha) + 1);
        fprintf('autarky output maximizing health level in North is %g%%\n', zY_aut*100);   
        
    % laissez-faire
        zLF = 1-q; ini = 280;
        [KNorthLF res exitflag] = fzero('LaissezFaire',ini,opt,paras,PHI);
        %res
        fprintf('KNorth: %g, share of healthy workers (laissez-faire): %g%%\n', KNorthLF(1), zLF*100);
        
    % union safety level
        ini = [280; .9]; flag = NaN;
        [zSol res exitflag] = fsolve('UnionHealthAndInterestRates',ini,opt,paras,PHI,flag);
        KNorthUnion=zSol(1);
        zNorthUnion=zSol(2);
        fprintf('KNorth: %g, share of healthy workers (firm level union): %g%%\n', KNorthUnion, zNorthUnion*100);
        
    % output planner safety level
        [zSolPlanner res exitflag] = fsolve('OutputHealthAndInterestRates',ini,opt,paras,PHI);
        KNorthPlanner=zSolPlanner(1);
        zNorthPlanner=zSolPlanner(2);
        fprintf('KNorth: %g, share of healthy workers (output planner): %g%%\n', KNorthPlanner, zNorthPlanner*100);
        
%        disp('.')
 %       disp('done with output planner')
  %      disp('.')
        
    % welfare planner safety level
        s_ini = log((1-zNorthPlanner)/q)/(-chi);
        ini_s = [KNorthPlanner s_ini];
        [zSolWelfare res exitflag] = fsolve('WelfareHealthAndInterestRates',ini_s,opt,paras,PHI,KNorthUnion);
   %     disp('done with fsolve WelfareHealthAndInterestRates')
        %exitflag
        %res
        KNorthWelfarePlannerVia_s=zSolWelfare(1);
        sNorthWelfarePlanner=zSolWelfare(2);
        zNorthWelfarePlannerVia_s = 1 - q*exp(-chi*sNorthWelfarePlanner);
        fprintf('KNorth: %g, share of healthy workers (welfare planner (via s)): %g\n', KNorthWelfarePlannerVia_s, zNorthWelfarePlannerVia_s*100);
        
    % compute s given z starting from z=1-qBar*e^(-chi*s)
        zVector = [zY_aut zNorthUnion zNorthPlanner zNorthWelfarePlannerVia_s];
        sVector = -log((1-zVector)/q)/chi;
        
%% globalization effects on northern safety
    
    fprintf('\n==== healthy and happy without globalization?\n\n')

    % compute safety level in closed economy
            
        % capital stock in Canada in hypothetical autarky is 20% lower and
        % in Germany it is 6% higher
            CanadaCase = .8;
            GermanyCase = 1.06;
        % transport KNorth via paras (where there is KWorld - which is not
        % needed in closed economy)
            parasCanada = paras; parasGermany = paras;
            parasCanada(10) = CanadaCase * KNorthUnion;
            parasGermany(10) = GermanyCase * KNorthUnion;

        iniClosed = .9;
        [zWithoutGlobCAN res exitflag] = fsolve('UnionHealthClosedEconomy',iniClosed,opt,parasCanada,PHI);
        [zWithoutGlobGER res exitflag] = fsolve('UnionHealthClosedEconomy',iniClosed,opt,parasGermany,PHI);
        disp('share of healthy workers without globalization:')
        fprintf('     Countries with OUTflow of capital due to globalization (Germany): %g\n', zWithoutGlobGER);
        fprintf('     Countries with INflow  of capital due to globalization (Canada): %g\n', zWithoutGlobCAN);
        
        % what are GDP effects?
            
%            zWithGlob = .98;
%            PHIclosedCAN = (1/zWithoutGlobCAN - 1)*(1-alpha); % compute the PHI that corresponds to the closed economy
            TFPclosedCAN = b * ((1-zWithoutGlobCAN)/q)^PHI
            GDPClosedCanada = TFPclosedCAN * parasCanada(10)^alpha * (zWithoutGlobCAN * N)^(1-alpha);
            
%            PHIclosedGER = (1/zWithoutGlobGER - 1)*(1-alpha); % compute the PHI that corresponds to the closed economy
            TFPclosedGER = b * ((1-zWithoutGlobGER)/q)^PHI
            GDPClosedGermany = TFPclosedGER * parasGermany(10)^alpha * (zWithoutGlobGER * N)^(1-alpha);
            
%            PHItrade = (1/zWithGlob - 1)*(1-alpha); % PHI corresponding to data health level of .98
            TFPtrade = TFP(paras,PHI,'North');
            GDPOpen = TFPtrade * KNorthUnion^alpha * (zNorthUnion * N)^(1-alpha);
            
            fprintf('\n     GDP effects of globalization:\n')
            fprintf('     GDPtrade/GDPclosed for Canada: %g and for Germany: %g\n', GDPOpen/GDPClosedCanada, GDPOpen/GDPClosedGermany);
            r1 = TFPtrade/TFPclosedCAN;
            r2 = TFPtrade/TFPclosedGER;
            fprintf('     TFPtrade/TFPclosed for Canada: %g and for Germany: %g\n', r1, r2);

%% safety level in South rises   

    fprintf('\n==== safety level in South is now rising\n\n')

%	fprintf('lambda for rising zSouth %g\n',paras(9))
    
% start comparative statics
    zSouthIni = zSouthData; zNorthIni = zNorthData;
    for i = 0:10
        zSouth = zSouthIni + (zNorthIni-zSouthIni)*i/10;
        paras(4) = zSouth;
        
        % compute equilibrium
            ini = [250; .95];
            flag = 30;
            [zSol res exitflag] = fsolve('UnionHealthAndInterestRates',ini,opt,paras,PHI,flag);
%            exitflag
            KNorthZsouthRises(i+1)=zSol(1);
            zNorth(i+1)=zSol(2)*100;
            paras(3) = zSol(2);
            YNorth(i+1) = TFP(paras,PHI,'North') * KNorthZsouthRises(i+1)^alpha * (zSol(2) * N)^(1-alpha);
            YSouth(i+1) = TFP(paras,PHI,'South') * (KWorld -KNorthZsouthRises(i+1))^alpha * (zSouth * NSouth)^(1-alpha);

            zz = IntRate(KNorthZsouthRises(i+1),paras,PHI,'North');
            EquilIntRate(i+1) = zz;
    end;
    disp(sprintf('initial interest rate is %g percent', EquilIntRate(1)*100));
    
    zNorth
    
% plot result
    z = linspace(zSouthIni,zNorthIni,11);
    subplot(1,3,1)
    plot(z,KNorthZsouthRises/KWorld*100,z,zNorth,'o')
    %title('Share of capital in North (-) and health in North (o)');
    legend('Share of capital in North','Health in North')
    subplot(1,3,2)
    plot(z,YNorth+YSouth)
    title('World GDP');
    
% compute flows
    KSouth0 = KWorld - KNorthZsouthRises(1); KSouthEnd = KWorld - KNorthZsouthRises(10);
    InflowSouth = KSouthEnd - KSouth0;
    InflowNorth = - InflowSouth;
    KNorth0 = KNorthZsouthRises(1);
    GrowthCapitalStockSouth = InflowSouth/KSouth0*100;
    GrowthCapitalStockNorth = InflowNorth/KNorth0*100;
    disp(sprintf('inflow to South is %g, i.e. capital stock increases by %g percent', InflowSouth, GrowthCapitalStockSouth));
    fprintf('inflow to North is %g, i.e. capital stock increases by %g percent\n', InflowNorth, GrowthCapitalStockNorth);

% compute health and TFP changes 
    GrowthHealthNorth = zNorth(10)/zNorth(1) - 1;
    TFP1 = b * ((1-zNorth(1)/100)/q)^PHI; TFP10 = b * ((1-zNorth(10)/100)/q)^PHI;
    TFPchangeNorth = TFP10/TFP1 - 1;
    
    disp(sprintf('Health in North grows by %g%% and TFP by %g%%', GrowthHealthNorth*100,TFPchangeNorth*100));

    TFPini = b * ((1-.9)/q)^PHI
    TFPafter = b * ((1-.98)/q)^PHI
    TFPchangeSouth = (TFPafter/TFPini - 1)*100

    
    
% compute GDP changes
    GrowthGDPNorth = YNorth(10)/YNorth(1) - 1;
    GrowthGDPSouth = YSouth(10)/YSouth(1) - 1;
    disp(sprintf('GDP in North grows by %g, and in South by %g percent', GrowthGDPNorth*100, GrowthGDPSouth*100));
    GrowthGDPWorld = (YSouth(10)+YNorth(10))/(YSouth(1)+YNorth(1)) - 1;
    disp(sprintf('World GDP grows by %g percent', GrowthGDPWorld*100));
    
% look at GDP levels
    subplot(1,3,3)
    plot(z,YNorth,z,YSouth)
    legend('YNorth','YSouth')