function res = WelfareHealthAndInterestRates(x,paras,PHI,KNorthUnion)

%% load parameters and variables

% variables    
    KNorth = x(1); s = x(2);

% parameters    
    ExoParas = paras(1:13); parasNeu = paras(14:20);

% ExoParas
    alpha = ExoParas(1);  chi = ExoParas(2);                           zSouthData = ExoParas(4);
     phi  = ExoParas(5);     q  = ExoParas(6);                                  N  = ExoParas(8); 
  lambda  = ExoParas(9);                         NSouth = ExoParas(11);     YNorth = ExoParas(12);
   

% parasNeu
   mue = parasNeu(7);

%% prelims   
       
    % compute z 
        z = 1 - q*exp(-chi*s);
        
    % express A as function of z
        A = TFP(paras,PHI,'North');
        ASouth = TFP(paras,PHI,'South');

    % compute interest rates
        rNorth = IntRate(KNorth,paras,PHI,'North'); 
        rSouth = IntRate(KNorth,paras,PHI,'South'); 
        
    % compute Delta, the flow from North to South: 
    % computing Delta can be done only when looking at the data. 
    % As the paper points out, the autarky capital stock lies between
    % approx. 80% and 105% of the trade capital stock
    
        KNorthAutarky = 1.05 * KNorthUnion;
        Delta = KNorthAutarky - KNorth;
        share = rNorth*Delta/YNorth;

    % compute health
        epsi_As = phi * s;
        epsi_zs = (1/z-1) * chi * s;
        
        C = YNorth + rNorth*Delta;
        aux = (1-mue)/mue*(z/C)^lambda;
        epsi_UC = 1/(1+aux);
        epsi_Uz = 1/(1+1/aux);
        epsi_rA = 1/(1+(A/ASouth)^(1/(1-alpha))*zSouthData*NSouth/z/N);
        
%% main

    % health equations
        LHS = epsi_As/epsi_zs;
        RHS = 1-alpha + epsi_Uz/epsi_UC * (1+share)/(1+epsi_rA*share);
        
    % return residua
        res = [rNorth-rSouth RHS-LHS];
end